/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_6fxbBbmV);
  numBytes += sPhasor_k_init(&sPhasor_W3ii8SwL, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_ANnPw496);
  numBytes += sRPole_init(&sRPole_aVi3xOXB);
  numBytes += sRPole_init(&sRPole_ThDh7OTs);
  numBytes += sTabhead_init(&sTabhead_uHuM4Lim, &hTable_WZhHEspN);
  numBytes += sTabread_init(&sTabread_gVOj4YcW, &hTable_WZhHEspN, false);
  numBytes += sTabread_init(&sTabread_YgUU8mM7, &hTable_WZhHEspN, false);
  numBytes += sLine_init(&sLine_9dquJqFb);
  numBytes += sTabhead_init(&sTabhead_rX8VIQXE, &hTable_0MR0LJzM);
  numBytes += sTabread_init(&sTabread_eV9Vg03K, &hTable_0MR0LJzM, false);
  numBytes += sTabread_init(&sTabread_nLqjICPR, &hTable_0MR0LJzM, false);
  numBytes += sLine_init(&sLine_M5Im0fry);
  numBytes += sTabwrite_init(&sTabwrite_Ud5I4Ns2, &hTable_0MR0LJzM);
  numBytes += sTabwrite_init(&sTabwrite_okZ3swTT, &hTable_WZhHEspN);
  numBytes += cVar_init_f(&cVar_S87IsCrl, 0.0f);
  numBytes += cVar_init_f(&cVar_EM4agVrJ, 0.0f);
  numBytes += cVar_init_f(&cVar_u1FJNfjE, 0.0f);
  numBytes += cVar_init_f(&cVar_SQbh5ARS, 0.0f);
  numBytes += cVar_init_s(&cVar_Oc5mucFT, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_Psego1e8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8aA7Ky3j, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f8DSyNW8, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_QOfCUWww, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_UcYOCVCI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sicoA8TU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fSoDaLiQ, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_5dzUM900, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tyyR5WBA, 0.0f);
  numBytes += hTable_init(&hTable_0MR0LJzM, 256);
  numBytes += cDelay_init(this, &cDelay_NYyif6X7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vsSijniG, 0.0f);
  numBytes += hTable_init(&hTable_WZhHEspN, 256);
  numBytes += cVar_init_f(&cVar_SGYaYw1m, 14.0f);
  numBytes += cBinop_init(&cBinop_Idv92YiB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ncpRfXv1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EJfFl377, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Thf78kHX, 14.0f);
  numBytes += cBinop_init(&cBinop_ekp5usUS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_T9iARfbO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hzMzioQ3, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_RReRTSiT, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_rhdVRz2y, 1, -1);
  numBytes += cVar_init_f(&cVar_B3aQFkiz, 0.2f);
  numBytes += cSlice_init(&cSlice_x0YtofYl, 1, -1);
  numBytes += cVar_init_f(&cVar_IPMVSmwZ, 0.0f);
  numBytes += cSlice_init(&cSlice_DBc4QhJW, 1, -1);
  numBytes += cVar_init_f(&cVar_QxTXy4lX, 2.0f);
  numBytes += cSlice_init(&cSlice_OznrCuAT, 1, -1);
  numBytes += cVar_init_f(&cVar_aT8pwlU9, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_0MR0LJzM);
  hTable_free(&hTable_WZhHEspN);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_0MR0LJzM; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_WZhHEspN; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9GgX680L_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o6Q1VBbz_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W3mhS9yZ_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xcPm9YCm_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_65dQPwFi_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tA2E3lK2_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HHszWABp_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VuLX0PZ3_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r8EQAetc_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_S87IsCrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVPYKboe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_EM4agVrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NX3PyJsg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_u1FJNfjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JuefApj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_SQbh5ARS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jVjvV8Ia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_yWT4pDqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yZgqBmQu_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yZgqBmQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_W3ii8SwL, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_jio9P4R4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wLUbxoPs_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_wLUbxoPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xH87iqpk_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_Oc5mucFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cz6SgudV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_2lj9P4IH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZBn49hwr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Psego1e8, m);
}

void Heavy_WSTD_FLANGR::cBinop_xH87iqpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8aA7Ky3j, m);
}

void Heavy_WSTD_FLANGR::cMsg_Cz6SgudV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2lj9P4IH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ZBn49hwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_f8DSyNW8, m);
}

void Heavy_WSTD_FLANGR::cMsg_TUur9hN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OfhfUEaB_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_OfhfUEaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Dmwye6Z9_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_QOfCUWww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZUYQ3TSQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_LF4oEYGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qDZXHNzc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UcYOCVCI, m);
}

void Heavy_WSTD_FLANGR::cBinop_Dmwye6Z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sicoA8TU, m);
}

void Heavy_WSTD_FLANGR::cMsg_ZUYQ3TSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LF4oEYGo_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_qDZXHNzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fSoDaLiQ, m);
}

void Heavy_WSTD_FLANGR::cBinop_egssEqRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_K6ibyAoe_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_K6ibyAoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Xytiuw8j_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_WsZDRrX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0E31ls0t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_6a0LjslX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SzijegoU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Xytiuw8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8xA9ry40_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8xA9ry40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_njPAtUqo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fnCJhvFW_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_fnCJhvFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lec8GeiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_njPAtUqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uTjCCgfU_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uTjCCgfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zmtS1p4o_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_lec8GeiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZTCJR28R_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ZTCJR28R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GDB71bx5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_zmtS1p4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WsZDRrX5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GDB71bx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_6a0LjslX_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Eu2pkp8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TZp6juWr_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_TZp6juWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8nby01dm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_BIpjrJZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_viPytfTc_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_viPytfTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_uhvEysX1_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_5dzUM900_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5dzUM900, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tyyR5WBA, 0, m, &cDelay_tyyR5WBA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5dzUM900, 0, m, &cDelay_5dzUM900_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Ud5I4Ns2, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_tyyR5WBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tyyR5WBA, m);
  cMsg_nZGSgWUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_u55SBRP2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EDyEyw30_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_mTx6DXTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PuxRFSTc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_0MR0LJzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JGuDk8ky_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5dzUM900, 2, m, &cDelay_5dzUM900_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_120tD8Lf_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_PuxRFSTc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0MR0LJzM, 0, m, &hTable_0MR0LJzM_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uhvEysX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_mTx6DXTV_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_nZGSgWUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0MR0LJzM, 0, m, &hTable_0MR0LJzM_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_120tD8Lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5dzUM900, 0, m, &cDelay_5dzUM900_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_JGuDk8ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_tyyR5WBA, 2, m, &cDelay_tyyR5WBA_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_EDyEyw30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Ud5I4Ns2, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_tgzhRfvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q9KI2Jzu_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_q9KI2Jzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yxCSZqEn_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_NYyif6X7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NYyif6X7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vsSijniG, 0, m, &cDelay_vsSijniG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYyif6X7, 0, m, &cDelay_NYyif6X7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_okZ3swTT, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_vsSijniG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vsSijniG, m);
  cMsg_SPS1vB7r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_megDedqn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_IHzQP5L0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_4UVJPFed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SJ6QiOpN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_WZhHEspN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rc8ccdDc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYyif6X7, 2, m, &cDelay_NYyif6X7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uyNn9fcn_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_SJ6QiOpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_WZhHEspN, 0, m, &hTable_WZhHEspN_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yxCSZqEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_4UVJPFed_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_SPS1vB7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_WZhHEspN, 0, m, &hTable_WZhHEspN_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_uyNn9fcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NYyif6X7, 0, m, &cDelay_NYyif6X7_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Rc8ccdDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_vsSijniG, 2, m, &cDelay_vsSijniG_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_IHzQP5L0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_okZ3swTT, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_SGYaYw1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Idv92YiB, HV_BINOP_MULTIPLY, 0, m, &cBinop_Idv92YiB_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_yXGFjvEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oQ4J4VFl_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_oQ4J4VFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mSHqJ7Qw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_Idv92YiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UOXND11j_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_AFMyvakb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Idv92YiB, HV_BINOP_MULTIPLY, 1, m, &cBinop_Idv92YiB_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_mSHqJ7Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AFMyvakb_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_UOXND11j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_B5HaRWFS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_B5HaRWFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_w0IMrgkr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EJfFl377, m);
}

void Heavy_WSTD_FLANGR::cBinop_w0IMrgkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ncpRfXv1, m);
}

void Heavy_WSTD_FLANGR::cVar_Thf78kHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ekp5usUS, HV_BINOP_MULTIPLY, 0, m, &cBinop_ekp5usUS_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_7vrdN1aX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1qqv5kVM_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_1qqv5kVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WWBqWhyo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_ekp5usUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SXOxlR98_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_yxZOfawq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ekp5usUS, HV_BINOP_MULTIPLY, 1, m, &cBinop_ekp5usUS_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_WWBqWhyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yxZOfawq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_SXOxlR98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OTkiyeFr_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_OTkiyeFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3iFXasMJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hzMzioQ3, m);
}

void Heavy_WSTD_FLANGR::cBinop_3iFXasMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_T9iARfbO, m);
}

void Heavy_WSTD_FLANGR::cMsg_8nby01dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ANnPw496, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_w8zdlUQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_URn2U9yv_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_qNBkqvWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_w8zdlUQp_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_xVDGrvLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XU3onNgW_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_ryZdKpMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8QsKP6S6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8QsKP6S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RReRTSiT, HV_BINOP_MULTIPLY, 1, m, &cBinop_RReRTSiT_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_XU3onNgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ryZdKpMH_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_RReRTSiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I9T3rUD8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_URn2U9yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RReRTSiT, HV_BINOP_MULTIPLY, 0, m, &cBinop_RReRTSiT_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_I9T3rUD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M5Im0fry, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_OUus145O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_vXvsfKa2_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_vXvsfKa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVDGrvLM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qNBkqvWB_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_hLpa7ucR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rhdVRz2y, 0, m, &cSlice_rhdVRz2y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3RrBN4gU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_rhdVRz2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6wJm0aFc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6wJm0aFc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_B3aQFkiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6wJm0aFc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_6wJm0aFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tA2E3lK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_3RrBN4gU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x0YtofYl, 0, m, &cSlice_x0YtofYl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0R5HuZzh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_x0YtofYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CSCPYQcR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CSCPYQcR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_IPMVSmwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CSCPYQcR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_CSCPYQcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_65dQPwFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_0R5HuZzh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DBc4QhJW, 0, m, &cSlice_DBc4QhJW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Kg2FzrCf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_DBc4QhJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OskX0DCl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OskX0DCl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_QxTXy4lX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OskX0DCl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_OskX0DCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VuLX0PZ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Kg2FzrCf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OznrCuAT, 0, m, &cSlice_OznrCuAT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_OznrCuAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_50ONoiM8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_50ONoiM8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_aT8pwlU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_50ONoiM8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_50ONoiM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HHszWABp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_0E31ls0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9dquJqFb, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_SzijegoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6fxbBbmV, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_jVjvV8Ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hLpa7ucR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_SVPYKboe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hLpa7ucR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_NX3PyJsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hLpa7ucR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_JuefApj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_hLpa7ucR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_at4xEnhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SQbh5ARS, 0, m, &cVar_SQbh5ARS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GZVubvfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S87IsCrl, 0, m, &cVar_S87IsCrl_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_VY2rYlD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u1FJNfjE, 0, m, &cVar_u1FJNfjE_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_VuLX0PZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_yWT4pDqu_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_65dQPwFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OUus145O_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_r8EQAetc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yXGFjvEB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SGYaYw1m, 0, m, &cVar_SGYaYw1m_sendMessage);
  cMsg_7vrdN1aX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Thf78kHX, 0, m, &cVar_Thf78kHX_sendMessage);
  cMsg_BIpjrJZv_sendMessage(_c, 0, m);
  cMsg_tgzhRfvN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B3aQFkiz, 0, m, &cVar_B3aQFkiz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IPMVSmwZ, 0, m, &cVar_IPMVSmwZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QxTXy4lX, 0, m, &cVar_QxTXy4lX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aT8pwlU9, 0, m, &cVar_aT8pwlU9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Oc5mucFT, 0, m, &cVar_Oc5mucFT_sendMessage);
  cMsg_jio9P4R4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QOfCUWww, 0, m, &cVar_QOfCUWww_sendMessage);
  cMsg_TUur9hN0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_HHszWABp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_egssEqRV_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_tA2E3lK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Eu2pkp8l_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_xcPm9YCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EM4agVrJ, 0, m, &cVar_EM4agVrJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_W3mhS9yZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_at4xEnhk_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_o6Q1VBbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_VY2rYlD9_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_9GgX680L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_GZVubvfL_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_6fxbBbmV, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_W3ii8SwL, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_ANnPw496, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_EJfFl377, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ncpRfXv1, VOf(Bf3));
    __hv_rpole_f(&sRPole_aVi3xOXB, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_hzMzioQ3, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_T9iARfbO, VOf(Bf4));
    __hv_rpole_f(&sRPole_ThDh7OTs, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_uHuM4Lim, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_8aA7Ky3j, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_f8DSyNW8, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_Psego1e8, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_gVOj4YcW, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_YgUU8mM7, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_9dquJqFb, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_rX8VIQXE, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_sicoA8TU, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_fSoDaLiQ, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_UcYOCVCI, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_eV9Vg03K, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_nLqjICPR, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_M5Im0fry, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_Ud5I4Ns2, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_okZ3swTT, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
