/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalDel1.h"
#include "HvTable.h"
#include "HvControlSlice.h"
#include "HvSignalRPole.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvControlDelay.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvSignalTabread.h"
#include "HvControlVar.h"
#include "HvSignalPhasor.h"
#include "HvSignalVar.h"
#include "HvControlUnop.h"
#include "HvSignalLine.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_S87IsCrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EM4agVrJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u1FJNfjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SQbh5ARS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yWT4pDqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yZgqBmQu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jio9P4R4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wLUbxoPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Oc5mucFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2lj9P4IH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xH87iqpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Cz6SgudV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZBn49hwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TUur9hN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OfhfUEaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QOfCUWww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LF4oEYGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dmwye6Z9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZUYQ3TSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qDZXHNzc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_egssEqRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K6ibyAoe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WsZDRrX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_6a0LjslX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Xytiuw8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8xA9ry40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fnCJhvFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_njPAtUqo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uTjCCgfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lec8GeiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZTCJR28R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zmtS1p4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GDB71bx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Eu2pkp8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZp6juWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BIpjrJZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_viPytfTc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5dzUM900_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_tyyR5WBA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_u55SBRP2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_mTx6DXTV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0MR0LJzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PuxRFSTc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uhvEysX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nZGSgWUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_120tD8Lf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JGuDk8ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDyEyw30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tgzhRfvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_q9KI2Jzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NYyif6X7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_vsSijniG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_megDedqn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_4UVJPFed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_WZhHEspN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SJ6QiOpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yxCSZqEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SPS1vB7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uyNn9fcn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rc8ccdDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IHzQP5L0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SGYaYw1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yXGFjvEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oQ4J4VFl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Idv92YiB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AFMyvakb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSHqJ7Qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UOXND11j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B5HaRWFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w0IMrgkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Thf78kHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7vrdN1aX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1qqv5kVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ekp5usUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yxZOfawq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WWBqWhyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SXOxlR98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OTkiyeFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3iFXasMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8nby01dm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_w8zdlUQp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qNBkqvWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xVDGrvLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ryZdKpMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8QsKP6S6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XU3onNgW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RReRTSiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_URn2U9yv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I9T3rUD8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OUus145O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXvsfKa2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hLpa7ucR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rhdVRz2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B3aQFkiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6wJm0aFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3RrBN4gU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_x0YtofYl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IPMVSmwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CSCPYQcR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0R5HuZzh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DBc4QhJW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QxTXy4lX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OskX0DCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Kg2FzrCf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OznrCuAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aT8pwlU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_50ONoiM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0E31ls0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SzijegoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jVjvV8Ia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SVPYKboe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NX3PyJsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JuefApj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_at4xEnhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GZVubvfL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VY2rYlD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VuLX0PZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_65dQPwFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r8EQAetc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HHszWABp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tA2E3lK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xcPm9YCm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_W3mhS9yZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o6Q1VBbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9GgX680L_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_6fxbBbmV;
  SignalPhasor sPhasor_W3ii8SwL;
  SignalLine sLine_ANnPw496;
  SignalRPole sRPole_aVi3xOXB;
  SignalRPole sRPole_ThDh7OTs;
  SignalTabhead sTabhead_uHuM4Lim;
  SignalTabread sTabread_gVOj4YcW;
  SignalTabread sTabread_YgUU8mM7;
  SignalLine sLine_9dquJqFb;
  SignalTabhead sTabhead_rX8VIQXE;
  SignalTabread sTabread_eV9Vg03K;
  SignalTabread sTabread_nLqjICPR;
  SignalLine sLine_M5Im0fry;
  SignalTabwrite sTabwrite_Ud5I4Ns2;
  SignalTabwrite sTabwrite_okZ3swTT;
  ControlVar cVar_S87IsCrl;
  ControlVar cVar_EM4agVrJ;
  ControlVar cVar_u1FJNfjE;
  ControlVar cVar_SQbh5ARS;
  ControlBinop cBinop_yWT4pDqu;
  ControlBinop cBinop_yZgqBmQu;
  ControlVar cVar_Oc5mucFT;
  ControlBinop cBinop_xH87iqpk;
  ControlBinop cBinop_ZBn49hwr;
  SignalVarf sVarf_Psego1e8;
  SignalVarf sVarf_8aA7Ky3j;
  SignalVarf sVarf_f8DSyNW8;
  ControlVar cVar_QOfCUWww;
  ControlBinop cBinop_Dmwye6Z9;
  ControlBinop cBinop_qDZXHNzc;
  SignalVarf sVarf_UcYOCVCI;
  SignalVarf sVarf_sicoA8TU;
  SignalVarf sVarf_fSoDaLiQ;
  ControlBinop cBinop_egssEqRV;
  ControlBinop cBinop_K6ibyAoe;
  ControlBinop cBinop_Xytiuw8j;
  ControlBinop cBinop_8xA9ry40;
  ControlBinop cBinop_uTjCCgfU;
  ControlBinop cBinop_ZTCJR28R;
  ControlBinop cBinop_zmtS1p4o;
  ControlBinop cBinop_GDB71bx5;
  ControlBinop cBinop_Eu2pkp8l;
  ControlBinop cBinop_TZp6juWr;
  ControlDelay cDelay_5dzUM900;
  ControlDelay cDelay_tyyR5WBA;
  ControlBinop cBinop_mTx6DXTV;
  HvTable hTable_0MR0LJzM;
  ControlBinop cBinop_uhvEysX1;
  ControlDelay cDelay_NYyif6X7;
  ControlDelay cDelay_vsSijniG;
  ControlBinop cBinop_4UVJPFed;
  HvTable hTable_WZhHEspN;
  ControlBinop cBinop_yxCSZqEn;
  ControlVar cVar_SGYaYw1m;
  ControlBinop cBinop_Idv92YiB;
  ControlBinop cBinop_AFMyvakb;
  SignalVarf sVarf_ncpRfXv1;
  ControlBinop cBinop_UOXND11j;
  ControlBinop cBinop_B5HaRWFS;
  ControlBinop cBinop_w0IMrgkr;
  SignalVarf sVarf_EJfFl377;
  ControlVar cVar_Thf78kHX;
  ControlBinop cBinop_ekp5usUS;
  ControlBinop cBinop_yxZOfawq;
  SignalVarf sVarf_T9iARfbO;
  ControlBinop cBinop_SXOxlR98;
  ControlBinop cBinop_OTkiyeFr;
  ControlBinop cBinop_3iFXasMJ;
  SignalVarf sVarf_hzMzioQ3;
  ControlBinop cBinop_ryZdKpMH;
  ControlBinop cBinop_8QsKP6S6;
  ControlBinop cBinop_XU3onNgW;
  ControlBinop cBinop_RReRTSiT;
  ControlBinop cBinop_URn2U9yv;
  ControlBinop cBinop_OUus145O;
  ControlBinop cBinop_vXvsfKa2;
  ControlSlice cSlice_rhdVRz2y;
  ControlVar cVar_B3aQFkiz;
  ControlSlice cSlice_x0YtofYl;
  ControlVar cVar_IPMVSmwZ;
  ControlSlice cSlice_DBc4QhJW;
  ControlVar cVar_QxTXy4lX;
  ControlSlice cSlice_OznrCuAT;
  ControlVar cVar_aT8pwlU9;
  ControlBinop cBinop_at4xEnhk;
  ControlBinop cBinop_GZVubvfL;
  ControlBinop cBinop_VY2rYlD9;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
